What's this
---------------------------------

This is a `KyotoTycoon`_ client for Python.

It is fast, written in C.

Require
---------------------------------

pykt requires **Python 2.x >= 2.5**. 

kyototycoon 0.9.39 +.

Installation
---------------------------------

Install from pypi::

  $ easy_install -ZU pykt

Install from source:: 

  $ python setup.py install


.. _KyotoTycoon: http://fallabs.com/kyototycoon/


